@@ -14,7 +14,6 @@
 
 from tempest import clients
 
-from monasca_tempest_tests.services import log_api_v2_client
 from monasca_tempest_tests.services import log_api_v3_client
 from monasca_tempest_tests.services import log_search_client
 
@@ -23,18 +22,12 @@ class Manager(clients.Manager):
     def __init__(self, credentials=None):
         super(Manager, self).__init__(credentials)
 
-        self.log_api_clients = {
-            "v2": log_api_v2_client.LogApiV2Client(
-                self.auth_provider,
-                'logs_v2',
-                None
-            ),
-            "v3": log_api_v3_client.LogApiV3Client(
-                self.auth_provider,
-                'logs',
-                None
-            )
-        }
+        self.log_api_client = log_api_v3_client.LogApiV3Client(
+            self.auth_provider,
+            'logs',
+            None
+        )
+
         self.log_search_client = log_search_client.LogsSearchClient(
             self.auth_provider,
             'logs-search',
